rabbitmq_retry

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2024 License: MIT Imports: 4 Imported by: 0

README

rabbitmq-retry

Golang package that will allow developers to create a rabbitmq exchange and queue with a backing dead letter exchange and queue which will allow for automatic retries after a specified amount of time.

Documentation

Index

Constants

This section is empty.

Variables

var Channel *amqp.Channel
var Queue amqp.Queue

Functions

func Close

func Close()

func Initialize

func Initialize(exchangeName, queueName string, millisecondsBeforeRetry int)

Types

This section is empty.

Directories

Path Synopsis

Jump to